==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebSearchInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSearchInfoDescription } from "./WebSearchInfoDescription";
/**
 * @hidden
 */
var WebSearchInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSearchInfoDescriptionMetadata, _super);
    function WebSearchInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSearchInfoDescriptionMetadata.b = function (a) {
        if (WebSearchInfoDescriptionMetadata.a == null) {
            WebSearchInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSearchInfoDescriptionMetadata.c(WebSearchInfoDescriptionMetadata.a);
        }
        if (a.k(WebSearchInfoDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebSearchInfoDescriptionMetadata.a);
    };
    WebSearchInfoDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SearchInfo");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("SearchText", "String");
        a.item("CaseSensitive", "Boolean");
        a.item("ExactMatch", "Boolean");
        a.item("ActiveMatchIndex", "Number:double");
        a.item("MatchInfoCacheRef", "(w:MatchInfoCache,wf:MatchInfoCache)DataRef:object");
    };
    WebSearchInfoDescriptionMetadata.d = function (a) {
        WebSearchInfoDescriptionMetadata.b(a);
        a.ad("WebSearchInfo", function () { return new WebSearchInfoDescription(); });
        a.ac("WebSearchInfo", WebSearchInfoDescriptionMetadata.a);
    };
    WebSearchInfoDescriptionMetadata.$t = markType(WebSearchInfoDescriptionMetadata, 'WebSearchInfoDescriptionMetadata');
    WebSearchInfoDescriptionMetadata.a = null;
    return WebSearchInfoDescriptionMetadata;
}(Base));
export { WebSearchInfoDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebSearchInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseSearchInfoDescriptionMetadata } from "./WebBaseSearchInfoDescriptionMetadata";
import { WebSearchInfoDescription } from "./WebSearchInfoDescription";
/**
 * @hidden
 */
var WebSearchInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSearchInfoDescriptionMetadata, _super);
    function WebSearchInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSearchInfoDescriptionMetadata.b = function (a) {
        if (WebSearchInfoDescriptionMetadata.a == null) {
            WebSearchInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSearchInfoDescriptionMetadata.c(WebSearchInfoDescriptionMetadata.a);
        }
        if (a.k(WebSearchInfoDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebSearchInfoDescriptionMetadata.a);
    };
    WebSearchInfoDescriptionMetadata.c = function (a) {
        WebBaseSearchInfoDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:SearchInfo");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("MatchInfoCacheRef", "(w:MatchInfoCache,wf:MatchInfoCache)DataRef:object");
        a.item("ActiveMatchIndex", "Number:double");
    };
    WebSearchInfoDescriptionMetadata.d = function (a) {
        WebSearchInfoDescriptionMetadata.b(a);
        a.ae("WebSearchInfo", function () { return new WebSearchInfoDescription(); });
        a.ad("WebSearchInfo", WebSearchInfoDescriptionMetadata.a);
    };
    WebSearchInfoDescriptionMetadata.$t = markType(WebSearchInfoDescriptionMetadata, 'WebSearchInfoDescriptionMetadata');
    WebSearchInfoDescriptionMetadata.a = null;
    return WebSearchInfoDescriptionMetadata;
}(Base));
export { WebSearchInfoDescriptionMetadata };
